Destination

Enum Destination 

pub enum Destination {
    All,
    NoTap,
    Forwarded(Vec<U256>),
    Handled(usize),
}
The Destination of the message, and also handles forwarded messages to make sure no loop is created.

Variants



All

To all handlers in this broker



NoTap

Only to handlers which represent no tap - useful for tests



Forwarded(Vec<U256>)

A forwarded message, with the IDs of the brokers which already handled that message



Handled(usize)

Tags a message as coming from this handler, to avoid putting it back into the same handler