pub struct PeerInfo {
pub id_init: NodeID,
pub id_follow: NodeID,
pub message: PeerMessage,
}Expand description
Data sent between two nodes using the signalling server to set up a peer-to-peer connection over WebRTC.
Fields
id_init: NodeIDThe ID of the node sending the PeerMessage::Init message: the
creator of the outgoing connection
id_follow: NodeIDThe ID of the node receiving the PeerMessage::Init message: the
creator of the incoming connection
message: PeerMessageThe actual data to be sent to the WebRTC subsystem
Implementations
Sourceimpl PeerInfo
impl PeerInfo
Sourcepub fn new(init: &NodeID, follow: &NodeID) -> PeerInfo
pub fn new(init: &NodeID, follow: &NodeID) -> PeerInfo
Creates a new PeerInfo with an init message
Sourcepub fn get_remote(&self, local: &NodeID) -> Option<NodeID>
pub fn get_remote(&self, local: &NodeID) -> Option<NodeID>
Gets the other ID given one of the two IDs
Sourcepub fn get_direction(&self, local: &NodeID) -> Direction
pub fn get_direction(&self, local: &NodeID) -> Direction
Gets the direction of the setup given the local ID